import * as vscode from 'vscode';
import { QuickPickItem } from "vscode";

function codeGeneratorQuickPickLogic(): undefined {
    const textEditor = vscode.window.activeTextEditor;
    if (!textEditor) {
        return undefined;
    }
    let thenable = vscode.window.showQuickPick(
        [
            {
                label: "Namespace",
                detail: "Namespace",
                output: "%namespace%"
            }, {
                label: "Class name",
                detail: "Segments Minus One (Object || Array)",
                output: "%ClassName%"
            }, {
                label: "Type",
                detail: "Segments Minus One (!Object && !Array)",
                output: "%Type%"
            }, {
                label: "Suggested Type",
                detail: "Type based on values in *.json file",
                output: "%SuggestedType%"
            }, {
                label: "Full Path",
                detail: "Full Path and name in padded format",
                output: "%Debug%"
            }, {
                label: "Name",
                detail: "Segments Last only name (no path)",
                output: "%Name%"
            }, {
                label: "Name for Suggested Type",
                detail: "Segments name (full)",
                output: "%FullName%"
            }, {
                label: "Class name (Camel-Cased)",
                detail: "Segments Minus One (Object || Array)",
                output: "%ClassNameCamelCased%"
            }, {
                label: "xType (Camel-Cased)",
                detail: "Segments Minus One (!Object && !Array)",
                output: "%xTypeCamelCased%"
            }, {
                label: "xSuggested Type (Camel-Cased)",
                detail: "Type based on values in *.json file",
                output: "%xSuggestedTypeCamelCased%"
            }, {
                label: "Full Path (Camel-Cased)",
                detail: "Full Path and name in padded format",
                output: "%DebugCamelCased%"
            }, {
                label: "Name (Humanized)",
                detail: "Segments Last only name (no path)",
                output: "%NameHumanized%"
            }, {
                label: "Name (Camel-Cased)",
                detail: "Segments Last only name (no path)",
                output: "%NameCamelCased%"
            }, {
                label: "Name (Camel-Cased and Plural)",
                detail: "Segments Last only name (no path)",
                output: "%NameCamelPlural%"
            }, {
                label: "Name for Suggested Type (Humanized)",
                detail: "Segments Last only name (no path)",
                output: "%FullNameHumanized%"
            }, {
                label: "Name for Suggested Type (Camel-Cased)",
                detail: "Segments Last only name (no path)",
                output: "%FullNameCamelCased%"
            }, {
                label: "Name for Suggested Type (Camel-Cased and Plural)",
                detail: "Segments Last only name (no path)",
                output: "%FullNameCamelPlural%"
            }, {
                label: "Partial Name for Suggested Type (Humanized)",
                detail: "Segments Last only name (no path)",
                output: "%PartialNameHumanized%"
            }, {
                label: "Collection Partial Name for Suggested Type (Humanized)",
                detail: "Segments Last only name (no path)",
                output: "%CollectionPartialNameHumanized%"
            }
        ]
    ).then(item => {
        if (!item) {
            return;
        }
        const selection = textEditor.selection;
        return textEditor.edit(editBuilder => {
            var range;
            if (selection.isEmpty) {
                editBuilder.insert(selection.start, item.output)
            }
            else {
                range = new vscode.Range(selection.start.line, selection.start.character, selection.end.line, selection.end.character);
                editBuilder.replace(range, item.output);
            }
        });
    });
    return undefined;
}

export const codeGeneratorQuickPick = () => codeGeneratorQuickPickLogic();